"""TOON Converter configuration module."""

from .constants import (
    MAX_NESTING_DEPTH,
    MAX_ROWS,
    MEMORY_WARNING_THRESHOLD_MB,
    MEMORY_CONFIRMATION_THRESHOLD_MB,
    SUPPORTED_FORMATS,
    DELIMITER_MAP,
)

__all__ = [
    "MAX_NESTING_DEPTH",
    "MAX_ROWS",
    "MEMORY_WARNING_THRESHOLD_MB",
    "MEMORY_CONFIRMATION_THRESHOLD_MB",
    "SUPPORTED_FORMATS",
    "DELIMITER_MAP",
]
